within CAES_Eleves.Components;

model Cavity "Modèle de cavité, couplée à un réservoir infini à T=40°C, initialisée avec une pression et une température. Du fluide rentre ou sort avec un débit massique et une enthalpie à affecter dans le connecteur"
  Connectors.FluidPort fluidPort annotation(
    Placement(visible = true, transformation(origin = {2, 86}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  parameter SI.Volume V = 140000;
  parameter SI.Temperature Tinit = 313.15;
  parameter SI.Pressure Pinit = 40e5;
  parameter SI.Area A = 16000 "Surface pour transfert thermique avec la terre";
  parameter SI.Temperature Tref = 313.15 "Température souterraine";
  parameter SI.CoefficientOfHeatTransfer h=30 "coeff. transfert avec la terre";
  SI.Mass M_air(start = Pinit / r / Tinit * V) "Masse totale dans le volume";
  SI.Density rho_air(start = Pinit / r / Tinit);
  SI.Temperature T_air(start = Tinit,fixed=true);
  SI.Pressure p_air(start = Pinit,fixed=true);
  SI.SpecificEnthalpy hin "inlet SpecificEnthalpy";
  SI.SpecificEnthalpy h_air "SpecificEnthalpy dans le volume";
  SI.Enthalpy H_air "Enthalpy dans le volume";
  SI.Energy U_air "Energy dans le volume";
  SI.MassFlowRate qm "Mass flow rate";
equation
  qm = fluidPort.m_flow;
  hin = inStream(fluidPort.h_outflow);
  //Reverse flow equation
  fluidPort.h_outflow = h_air;
  p_air = fluidPort.p;
// --------------------------------------- //
//            DEBUT PARTIE A COMPLETER     //  
// --------------------------------------- //
  
// Il faut déterminer l'évolution temporelle:
// -de la masse d'air dans la cavité
// -de la pression d'air dans la cavité
// -de la température d'air dans la cavité
// En utilisant les variables définies
// Et un modèle Q = h A Delta(T) pour le 
// transfert thermique avec la terre

// --------------------------------------- //
//            FIN   PARTIE A COMPLETER     //  
// --------------------------------------- //
  assert(p_air<73e5,"Maximum pressure in the cavity");
  annotation (Documentation(info="<html>
<p> <i>Des trous à compléter :</i> </p>
<p> Il faut déterminer l'évolution temporelle:
<ul>
<li>de la masse d'air dans la cavité;</li>
<li>de la pression d'air dans la cavité;</li>
<li>de la température d'air dans la cavité.</li>
</ul>
</p>
</html>"));
  annotation(
    Icon(graphics = {Polygon(origin = {8, -7}, points = {{-18, 87}, {-18, 67}, {-28, 59}, {-38, 55}, {-50, 47}, {-46, 37}, {-50, 23}, {-54, 15}, {-60, 5}, {-48, -37}, {-24, -85}, {0, -87}, {18, -81}, {28, -67}, {48, -65}, {60, -55}, {58, -43}, {48, -39}, {46, -25}, {34, -23}, {42, -9}, {52, 19}, {58, 43}, {48, 55}, {36, 57}, {14, 59}, {4, 67}, {4, 87}, {-18, 87}})}));
end Cavity;