within CAES_Eleves.Components;

model IdealHeatExchanger "Un modèle d'échangeur de chaleur idéal"
  Connectors.FluidPort inlet annotation(
    Placement(visible = true, transformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Connectors.FluidPort outlet annotation(
    Placement(visible = true, transformation(origin = {92, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Connectors.HeatPort heatPort annotation(
    Placement(visible = true, transformation(origin = {2, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {2, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  SI.MassFlowRate qm "Mass flow rate";
  SI.SpecificEnthalpy hin "Inlet enthalpy";
  SI.SpecificEnthalpy hout "Outlet enthalpy";
  SI.Temperature Tin "Inlet temperature";
  SI.Temperature Tout "Outlet temperature";
equation
  qm = inlet.m_flow;
  hin = inStream(inlet.h_outflow);
  outlet.h_outflow = hout;
//Reverse flow equation
  inlet.h_outflow = inStream(outlet.h_outflow);
//Ideal gas enthalpy / temperature
  Tin = hin / cp;
  Tout = hout / cp;
  Tout = heatPort.T;
  qm * (hout - hin) = heatPort.Q_flow;
//Pressure equilibrium
  inlet.p = outlet.p;
//Mass balance equation
  inlet.m_flow + outlet.m_flow = 0;
  annotation (Documentation(info="<html>
<p>  On a une entrée fluide, une sortie fluide et un connecteur thermique. On impose la température de sortie du fluide, le connecteur thermique permettant de mesurer la chaleur à fournir ou à extraire pour cela.
</p>
<p><i>Ce modèle est complet et fonctionnel.</i></p>
</html>"));
  annotation(
    Icon(graphics = {Rectangle(extent = {{-80, 40}, {80, -40}})}));
end IdealHeatExchanger;