within CAES_Eleves.Components;

model IdealHeatExchangerPinch "Modèle d'échangeur à contre-courant idéal, à pincement imposé"

//BRANCHE A
  Connectors.FluidPort inlet_A annotation(
    Placement(visible = true, transformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Connectors.FluidPort outlet_A annotation(
    Placement(visible = true, transformation(origin = {92, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  SI.MassFlowRate qm_A "Mass flow rate";
  SI.SpecificEnthalpy hin_A "Inlet enthalpy";
  SI.SpecificEnthalpy hout_A "Outlet enthalpy";
  SI.Temperature Tin_A "Inlet temperature";
  SI.Temperature Tout_A "Outlet temperature";
  
//BRANCHE B
  Connectors.FluidPort outlet_B annotation(
    Placement(visible = true, transformation(origin = {-88, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Connectors.FluidPort inlet_B annotation(
    Placement(visible = true, transformation(origin = {88, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  SI.MassFlowRate qm_B "Mass flow rate";
  SI.SpecificEnthalpy hin_B "Inlet enthalpy";
  SI.SpecificEnthalpy hout_B "Outlet enthalpy";
  SI.Temperature Tin_B "Inlet temperature";
  SI.Temperature Tout_B "Outlet temperature";
  
  parameter SI.TemperatureDifference Pinch "Pinch value or temperature difference";
  
equation
  qm_A = inlet_A.m_flow;
  qm_B = inlet_B.m_flow;
  
  hin_A = inStream(inlet_A.h_outflow);
  outlet_A.h_outflow = hout_A;
//Reverse flow equation
  inlet_A.h_outflow = inStream(outlet_A.h_outflow);
  
  hin_B = inStream(inlet_B.h_outflow);
  outlet_B.h_outflow = hout_B;
//Reverse flow equation
  inlet_B.h_outflow = inStream(outlet_B.h_outflow);  
  
//Ideal gas enthalpy / temperature
  Tin_A = hin_A / cp;
  Tout_A = hout_A / cp;

  Tin_B= hin_B / cp;
  Tout_B = hout_B / cp;

//Pressure equilibrium
  inlet_A.p = outlet_A.p;
  inlet_B.p = outlet_B.p;

//Mass balance equation
  inlet_A.m_flow + outlet_A.m_flow = 0;
  inlet_B.m_flow + outlet_B.m_flow = 0;
  
//Pincement  
  Tout_B-Tin_A=Pinch;
//Transfert thermique idéal
  qm_A * (hout_A - hin_A) + qm_B * (hout_B - hin_B)=0; 

annotation (Documentation(info="<html>
<p> Toute la chaleur perdue par une branche est transférée à l'autre.
</p>
<p><i>Ce modèle est complet et fonctionnel.</i></p>
</html>"));

  
  annotation(
    Icon(graphics = {Rectangle(extent = {{-80, 40}, {80, -40}}), Line(origin = {-1.34, 28.67}, points = {{-71, 0}, {71, 0}}, arrow = {Arrow.None, Arrow.Filled}, arrowSize = 6), Line(origin = {0.67, -28.65}, points = {{69, 0}, {-69, 0}}, arrow = {Arrow.None, Arrow.Filled}, arrowSize = 6), Text(origin = {3, 0}, extent = {{-63, 20}, {63, -20}}, textString = "Pinch=%Pinch")}));
end IdealHeatExchangerPinch;
